@@ -150,8 +150,9 @@ class CreateAudit(command.ShowOne):
             '-i', '--interval',
             dest='interval',
             metavar='<interval>',
-            help=_('Audit interval (in seconds). '
-                   "Only used if the audit is CONTINUOUS."))
+            help=_('Audit interval (in seconds or cron format). '
+                   'Cron inteval can be used like: "*/5 * * * *". '
+                   'Only used if the audit is CONTINUOUS.'))
         parser.add_argument(
             '-g', '--goal',
             dest='goal',
