@@ -32,11 +32,12 @@ AUDIT_TEMPLATE_SHORT_LIST_FIELD_LABELS = ['UUID', 'Name', 'Goal', 'Strategy']
 # Audit
 AUDIT_FIELDS = ['uuid', 'created_at', 'updated_at', 'deleted_at',
                 'state', 'audit_type', 'parameters', 'interval', 'goal_name',
-                'strategy_name', 'scope', 'auto_trigger']
+                'strategy_name', 'scope', 'auto_trigger', 'next_run_time']
 
 AUDIT_FIELD_LABELS = ['UUID', 'Created At', 'Updated At', 'Deleted At',
                       'State', 'Audit Type', 'Parameters', 'Interval', 'Goal',
-                      'Strategy', 'Audit Scope', 'Auto Trigger']
+                      'Strategy', 'Audit Scope', 'Auto Trigger',
+                      'Next Run Time']
 
 AUDIT_SHORT_LIST_FIELDS = ['uuid', 'audit_type',
                            'state', 'goal_name', 'strategy_name',
